<?php
/*
Plugin Name: WP Blog Vitals
Version: v1.4
Plugin URI: http://www.tipsandtricks-hq.com/?p=1322
Author: Ruhul Amin
Author URI: http://www.tipsandtricks-hq.com/
Description: Simple WordPress Stats Plugin to show Google Page Rank, Alexa rank, Technorati rank, Number of Posts, Comments etc anywhere on your blog to show off to your visitors.
*/

/*
    This program is free software; you can redistribute it
    under the terms of the GNU General Public License version 2,
    as published by the Free Software Foundation.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
*/

$siteurl = get_bloginfo('wpurl') ;
define('WP_VITALS_FOLDER', dirname(plugin_basename(__FILE__)));
//define('WP_VITALS_URL', get_option('siteurl').'/wp-content/plugins/' . WP_VITALS_FOLDER);
define('WP_VITALS_URL', WP_PLUGIN_URL.'/'.WP_VITALS_FOLDER);

define('WP_VITALS_PR_IMG_DIR', WP_VITALS_URL.'/images/pr-images/');
define('WP_VITALS_ALEXA_IMG_DIR', WP_VITALS_URL.'/images/alexa-images/');
define('WP_VITALS_TECHNORATI_IMG_DIR', WP_VITALS_URL.'/images/technorati-images/');
define('WP_VITALS_BLOG_DATA_IMG_DIR', WP_VITALS_URL.'/images/blog-data-images/');
define('WP_VITALS_SITE_URL', $siteurl);

$wp_blog_vitals_version = 1.4;

// Includes
include_once('vitals-pr-functions.php');
include_once('vitals-alexa-functions.php');
include_once('vitals-misc-functions.php');

// Some default options
add_option('wp_vitals_widget_title', 'Blog Vitals');
add_option('wp_vitals_show_doctor_image', '1');  
add_option('wp_vitals_show_pagerank', '1');
add_option('wp_vitals_show_alexa_rank', '1');
add_option('wp_vitals_cache_time', '86400');

function wp_blog_vitals_handler($atts)
{
	return print_wp_blog_vitals();
}

function filter_wp_blog_vitals_tag($content)
{
    if (strpos($content, "<!--wp_blog_vitals-->") !== FALSE)
    {
        $content = preg_replace('/<p>\s*<!--(.*)-->\s*<\/p>/i', "<!--$1-->", $content);
        $content = str_replace('<!--wp_blog_vitals-->', print_wp_blog_vitals(), $content);
    }
    return $content;
}

function print_wp_blog_vitals()
{
	if (get_option('wp_vitals_show_doctor_image') == 1)
	{
		$output .= '<a href="http://www.tipsandtricks-hq.com/?p=1322"><img src="'.WP_VITALS_URL.'/images/blog_vitals_doctor_48.jpg" title="Plugin by Tips N Tricks" alt="Blog Stats" /></a><br />';
	}
    
    if (get_option('wp_vitals_show_pagerank') == 1)
    {
	    if (!($pr_value_image = get_vitals_cache('pr_value_image')))
	    {
	        $pr_value_image = update_vitals_cache('pr_value_image', vitals_check_pagerank(WP_VITALS_SITE_URL, WP_VITALS_PR_IMG_DIR));
	    }
		$output .= '<img src="'.$pr_value_image.'" title="Google Page Rank" alt="Google Page Rank" />';
    }

    if (get_option('wp_vitals_show_alexa_rank') == 1)
    {
	    $alexa_rank = vitals_get_cached_alexa_rank(WP_VITALS_SITE_URL);
	    $rank_int_value = str_replace(',', '', $alexa_rank);
	    $alexa_rank_category_image = vitals_get_alexa_rank_image($rank_int_value, WP_VITALS_ALEXA_IMG_DIR);
	
	    $output .= '<table border="0" cellpadding="0" cellspacing="0">
	                <tr>
	                <td width="90" height="24" background="'.$alexa_rank_category_image.'" title="Alexa Rank" valign="top">
	                <div id="alexa_chicklet_text">'.$alexa_rank.'</div></td>
	                </tr>
	                </table>';
    }

    if (get_option('wp_vitals_show_technorati_rank') == 1)
    {
	    $technorati_rank = vitals_get_cached_technorati_rank(WP_VITALS_SITE_URL);
	    $technorati_image = WP_VITALS_TECHNORATI_IMG_DIR."technorati.png";
	    
	    $output .= '<table border="0" cellpadding="0" cellspacing="0">
	                <tr>
	                <td width="90" height="24" background="'.$technorati_image.'" title="Technorati Rank" valign="top">
	                <div id="technorati_chicklet_text">'.$technorati_rank.'</div></td>
	                </tr>
	                </table>';
    }
     
    if (get_option('wp_vitals_show_posts_count') == 1)
    {     
	    $posts_image = WP_VITALS_BLOG_DATA_IMG_DIR."posts.png";
	    $total_posts = vitals_get_post_count(); 
	    $output .= '<table border="0" cellpadding="0" cellspacing="0">
	                <tr>
	                <td width="90" height="24" background="'.$posts_image.'" title="Total Posts" valign="top">
	                <div id="posts_chicklet_text">'.$total_posts.'</div></td>
	                </tr>
	                </table>';
    }

    if (get_option('wp_vitals_show_comments_count') == 1)
    {                      
	    $comments_image = WP_VITALS_BLOG_DATA_IMG_DIR."comments.png";
	    $total_comments = vitals_get_cached_comments_count();
	    $output .= '<table border="0" cellpadding="0" cellspacing="0">
	                <tr>
	                <td width="90" height="24" background="'.$comments_image.'" title="Total Comments" valign="top">
	                <div id="comments_chicklet_text">'.$total_comments.'</div></td>
	                </tr>
	                </table>';
    }
           
    if (get_option('wp_vitals_show_pingbacks_count') == 1)
    {                    
	    $pingbacks_image = WP_VITALS_BLOG_DATA_IMG_DIR."pingbacks.png"; 
	    $total_pingbacks = vitals_get_cached_pingbacks_count();
	    $output .= '<table border="0" cellpadding="0" cellspacing="0">
	                <tr>
	                <td width="90" height="24" background="'.$pingbacks_image.'" title="Total Pingbacks" valign="top">
	                <div id="pingbacks_chicklet_text">'.$total_pingbacks.'</div></td>
	                </tr>
	                </table>';         
    }        

    if (get_option('wp_vitals_show_feedburner_count') == 1)
    {
    	$output .= '<table border="0" cellpadding="0" cellspacing="0">
	                <tr><td width="90" height="26" title="Feedburner Feed Count" valign="top">';
	    $fb_fc_code = get_option('wp_vitals_fb_fc_html');
	    $fb_fc_code = html_entity_decode($fb_fc_code, ENT_COMPAT);
	    $fb_fc_code = str_replace ('<p>', '', $fb_fc_code);
	    $fb_fc_code = str_replace ('</p>', '', $fb_fc_code);
	    if(!empty($fb_fc_code))
	    {
		    $output .=  $fb_fc_code;
		    $output .=  '</td></tr></table>';
	    }
	    else
	    {
	    	$output .= "<p>Feed count HTML code missing in the settings menu.</p>";
	    }
    }  	
	return $output;
}

function vitals_get_cached_post_count()
{
    if (!($cached_post_count = get_vitals_cache('vitals_post_count')))
    {
        $cached_post_count = update_vitals_cache('vitals_post_count', vitals_get_post_count());
    }
    return $cached_post_count;
}

function vitals_get_cached_comments_count()
{
    if (!($cached_comments_count = get_vitals_cache('vitals_comments_count')))
    {
        $cached_comments_count = update_vitals_cache('vitals_comments_count', vitals_get_comment_count());
    }
    return $cached_comments_count;
}

function vitals_get_cached_pingbacks_count()
{
    if (!($cached_pingbacks_count = get_vitals_cache('vitals_pingbacks_count')))
    {
        $cached_pingbacks_count = update_vitals_cache('vitals_pingbacks_count', vitals_get_trackback_count());
    }
    return $cached_pingbacks_count;
}

function vitals_get_cached_technorati_rank($url)
{
    if (!($cached_technorati_rank = get_vitals_cache('vitals_technorati_rank')))
    {
        $cached_technorati_rank = update_vitals_cache('vitals_technorati_rank', vitals_get_technorati_rank($url));
    }
    return $cached_technorati_rank;
}

function vitals_get_cached_alexa_rank($url)
{
    if (!($cached_alexa_rank = get_vitals_cache('alexa_rank')))
    {
        $cached_alexa_rank = update_vitals_cache('alexa_rank', vitals_get_alexa_method_2($url));
    }
    return $cached_alexa_rank;
}

/****** Caching stuff *********/
function get_vitals_cache($cacheID) 
{
    $vitals_global_cache_timeout = (int)get_option('wp_vitals_cache_time'); // This value is in seconds

    $cacheTimeout = get_option('vitals_cache_time_'.$cacheID);
    if ($cacheTimeout && (time() - $cacheTimeout < $vitals_global_cache_timeout))
    {
        return get_option('vitals_cache_data_'.$cacheID);
    }
    else 
    {
        return false;
    }    
}

function update_vitals_cache($cacheID, $value) 
{
    update_option('vitals_cache_time_'.$cacheID, time());
    update_option('vitals_cache_data_'.$cacheID, $value);
    return $value;
}
/******* End of Caching stuff ***********/

// Displays Wordpress Blog Vitals Options menu
function wp_blog_vitals_add_option_page() {
    if (function_exists('add_options_page')) {
        add_options_page('WP Blog Vitals', 'WP Blog Vitals', 8, __FILE__, 'wp_blog_vitals_options_page');
    }
}

function wp_blog_vitals_options_page() {

    global $wp_blog_vitals_version;
    
    if (isset($_POST['info_update']))
    {
        echo '<div id="message" class="updated fade"><p><strong>';

        update_option('wp_vitals_widget_title', (string)$_POST["wp_vitals_widget_title"]);
        update_option('wp_vitals_cache_time', (string)$_POST["wp_vitals_cache_time"]);
        update_option('wp_vitals_show_doctor_image', ($_POST['wp_vitals_show_doctor_image']=='1') ? '1':'-1' );
		update_option('wp_vitals_show_pagerank', ($_POST['wp_vitals_show_pagerank']=='1') ? '1':'-1' );
		update_option('wp_vitals_show_alexa_rank', ($_POST['wp_vitals_show_alexa_rank']=='1') ? '1':'-1' );
		update_option('wp_vitals_show_technorati_rank', ($_POST['wp_vitals_show_technorati_rank']=='1') ? '1':'-1' );
		update_option('wp_vitals_show_posts_count', ($_POST['wp_vitals_show_posts_count']=='1') ? '1':'-1' );
		update_option('wp_vitals_show_comments_count', ($_POST['wp_vitals_show_comments_count']=='1') ? '1':'-1' );
		update_option('wp_vitals_show_pingbacks_count', ($_POST['wp_vitals_show_pingbacks_count']=='1') ? '1':'-1' );
		update_option('wp_vitals_show_feedburner_count', ($_POST['wp_vitals_show_feedburner_count']=='1') ? '1':'-1' );
        $fb_html_code = htmlentities(stripslashes($_POST['wp_vitals_fb_fc_html']) , ENT_COMPAT);
        update_option('wp_vitals_fb_fc_html', $fb_html_code);
		
        echo 'Options Updated!';
        echo '</strong></p></div>';
    }

    ?>

    <div class=wrap>
    <div id="poststuff"><div id="post-body">

    <h2>WordPress Blog Vitals Settings v <?php echo $wp_blog_vitals_version; ?></h2>
    
    <p>For information and updates, please visit:<br />
    <a href="http://www.tipsandtricks-hq.com/?p=1322">http://www.tipsandtricks-hq.com/?p=1322</a></p>

	<div class="postbox">
	<h3><label for="title">Usage</label></h3>
	<div class="inside">

    <p>There are three ways you can use this plugin:</p>
    <ol>
    <li>Add the trigger text <strong>[wp_blog_vitals]</strong> to a post or page</li>
    <li>Call the function from a template file: <strong>&lt;?php echo print_wp_blog_vitals(); ?&gt;</strong></li>
    <li>Use the <strong>WP Blog Vitals</strong> Widget from the Widgets menu</li>
    </ol>

    </div></div>

    <form method="post" action="<?php echo $_SERVER["REQUEST_URI"]; ?>">
    <input type="hidden" name="info_update" id="info_update" value="true" />
    
	<div class="postbox">
	<h3><label for="title">WP Blog Vitals Plugin Options</label></h3>
	<div class="inside">
    <table width="100%" border="0" cellspacing="0" cellpadding="1">

    <tr valign="top"><td width="25%" align="left">
    <strong>Blog Vitals Widget Title:</strong>
    </td><td align="left">
    <input name="wp_vitals_widget_title" type="text" size="35" value="<?php echo get_option('wp_vitals_widget_title'); ?>" />
    <br /><i>This is the title of the blog vital widget</i>
    </td></tr><br />

    <tr valign="top"><td width="25%" align="left">
    <strong>Show Blog Vital Image : </strong>
    </td><td align="left">
    <input name="wp_vitals_show_doctor_image" type="checkbox"<?php if(get_option('wp_vitals_show_doctor_image')!='-1') echo ' checked="checked"'; ?> value="1" />
	<i> If unchecked the blog vital image won't be shown.</i>
	</td></tr>

    <tr valign="top"><td width="25%" align="left">
    <strong>Show Google PageRank : </strong>
    </td><td align="left">
    <input name="wp_vitals_show_pagerank" type="checkbox"<?php if(get_option('wp_vitals_show_pagerank')!='-1') echo ' checked="checked"'; ?> value="1" />
	<i> If checked the Google Page Rank will be shown to your visitors.</i>
	</td></tr>

    <tr valign="top"><td width="25%" align="left">
    <strong>Show Alexa Rank : </strong>
    </td><td align="left">
    <input name="wp_vitals_show_alexa_rank" type="checkbox"<?php if(get_option('wp_vitals_show_alexa_rank')!='-1') echo ' checked="checked"'; ?> value="1" />
	<i> If checked the Alexa Rank will be shown to your visitors.</i>
	</td></tr>

    <tr valign="top"><td width="25%" align="left">
    <strong>Show Technorati Rank : </strong>
    </td><td align="left">
    <input name="wp_vitals_show_technorati_rank" type="checkbox"<?php if(get_option('wp_vitals_show_technorati_rank')!='-1') echo ' checked="checked"'; ?> value="1" />
	<i> If checked the Technorait Rank will be shown to your visitors. Your blog will need to be registered with Technorati to get ranking.</i>
	</td></tr>	

    <tr valign="top"><td width="25%" align=left>
    <strong>Show Total Posts Count : </strong>
    </td><td align="left">
    <input name="wp_vitals_show_posts_count" type="checkbox"<?php if(get_option('wp_vitals_show_posts_count')!='-1') echo ' checked="checked"'; ?> value="1" />
	<i> If checked the total posts count of your blog will be shown to your visitors.</i>
	</td></tr>	

    <tr valign="top"><td width="25%" align="left">
    <strong>Show Total Comments Count : </strong>
    </td><td align="left">
    <input name="wp_vitals_show_comments_count" type="checkbox"<?php if(get_option('wp_vitals_show_comments_count')!='-1') echo ' checked="checked"'; ?> value="1" />
	<i> If checked the total comments count of your blog will be shown to your visitors.</i>
	</td></tr>	
	
    <tr valign="top"><td width="25%" align="left">
    <strong>Show Total Pingbacks Count : </strong>
    </td><td align="left">
    <input name="wp_vitals_show_pingbacks_count" type="checkbox"<?php if(get_option('wp_vitals_show_pingbacks_count')!='-1') echo ' checked="checked"'; ?> value="1" />
	<i> If checked the total pingbacks count of your blog will be shown to your visitors.</i>
	</td></tr>	

    <tr valign="top"><td width="25%" align="left">
    <strong>Show Feedburner Feed Count : </strong>
    </td><td align="left">
    <input name="wp_vitals_show_feedburner_count" type="checkbox"<?php if(get_option('wp_vitals_show_feedburner_count')!='-1') echo ' checked="checked"'; ?> value="1" />
	<i> If checked the feed count from Feedburner will be shown to your visitors.</i>
	</td></tr>	
	
    <tr valign="top"><td width="25%" align="left">
    <strong>Feed Count HTML Code from Feedburner: </strong>
    </td><td align="left">
    <textarea name="wp_vitals_fb_fc_html" rows="3" cols="35"><?php echo get_option('wp_vitals_fb_fc_html'); ?></textarea>	
	<br /><i>Copy the Feed Count HTML Code from your Feedburner account and paste it here.</i>
	</td></tr>			
	
    <tr valign="top"><td width="25%" align="left">
    <strong>Blog Vitals Cache Time: </strong>
    </td><td align="left">
    <input name="wp_vitals_cache_time" type="text" size="10" value="<?php echo get_option('wp_vitals_cache_time'); ?>" />
    <br /><i>This is the amount of time the stats are saved in cache for quicker page load. This value is in seconds. Set it to one day (86400 seconds) as these stats don't update frequently.</i>
    </td></tr>
    					
    </table>
    </div></div>

    <div class="submit">
        <input type="submit" name="info_update" value="<?php _e('Update options'); ?> &raquo;" />
    </div>

    </form>
    </div></div>
    </div><?php

}

function wp_blog_vitals_css()
{
    echo '<link type="text/css" rel="stylesheet" href="'.WP_VITALS_URL.'/wp_blog_vitals_style.css" />'."\n";
}

function show_wp_blog_vitals_widget($args)
{
	extract($args);
	
	$wp_vitals_widget_title = get_option('wp_vitals_widget_title');
	echo $before_widget;
	echo $before_title . $wp_vitals_widget_title . $after_title;
    echo print_wp_blog_vitals();
    echo $after_widget;
}

function wp_blog_vitals_widget_control()
{
    ?>
    <p>
    <? _e("Set the Plugin Settings from the Settings menu"); ?>
    </p>
    <?php

}
function widget_wp_blog_vitals_init()
{
    $widget_options = array('classname' => 'widget_wp_blog_vitals', 'description' => __( "Display WP Blog Vitals.") );
    wp_register_sidebar_widget('wp_blog_vitals_widgets', __('WP Blog Vitals'), 'show_wp_blog_vitals_widget', $widget_options);
    wp_register_widget_control('wp_blog_vitals_widgets', __('WP Blog Vitals'), 'wp_blog_vitals_widget_control' );
}

add_filter('the_content', 'filter_wp_blog_vitals_tag');

add_action('init', 'widget_wp_blog_vitals_init');

// Insert the wp_blog_vitals_add_option_page in the 'admin_menu'
add_action('admin_menu', 'wp_blog_vitals_add_option_page');

add_action('wp_head', 'wp_blog_vitals_css');
add_shortcode('wp_blog_vitals', 'wp_blog_vitals_handler');
?>